extension-added {#master}
--------------------------

### Bindings

#### SWIG

* Add support for `std::vector<short int>`
* Add extensions `sound2VecNonInterleaved()` `vecNonInterleaved2Sound()` `sound2VecInterleaved()` `vecInterleaved2Sound()` to Class yarp::sig::Sound